/* 
 * Portions Copyright (c) 2016 Analog Devices, Inc.
 *
 * Based on Device/ARM/ARMCM3/Source/GCC/gcc_arm.ld file in
 * ARM.CMSIS.4.5.0.pack.
 */

/* Linker script to configure memory regions. */
MEMORY
{
  /* Bootloader section in Flash */
  BSL (rx) : ORIGIN = 0x00000000, LENGTH = 62k
  
  /* App Vector Table section in Flash */
  VTABLE (rx) : ORIGIN = 0x0000F800, LENGTH = 0x180
  
  /* App section in Flash*/
  APP (rx) : ORIGIN = 0x0000F980, LENGTH = 192k - 0x180
  
  /* Info section in FLash */
  INFOMEM (rx) : ORIGIN = 0x0003F800, LENGTH = 2k
  
  /* SRAM used by the Bootloader */
  RAMBSL (rwx) : ORIGIN = 0x20000020, LENGTH = 16k - 0x20
  
  /* SRAM used by the App */
  RAMAPP (rwx) : ORIGIN = 0x20040000, LENGTH = 16k
}

/* Library configurations */
GROUP(libgcc.a libc.a libm.a libnosys.a)

 __bsl_reset_address = 0x0000199C;
ENTRY(__bsl_reset_address)

SECTIONS
{
	.bsl :
	{
		KEEP(*(.bsl))
	} > BSL
	
	.vectors :
	{
		KEEP(*(.vectors))
		__Vectors_End = .;
		__Vectors_Size = __Vectors_End - __Vectors;
		__end__ = .;
	} > VTABLE
	
	.text :
	{
		*(.text*)

		KEEP(*(.init))
		KEEP(*(.fini))

		/* .ctors */
		*crtbegin.o(.ctors)
		*crtbegin?.o(.ctors)
		*(EXCLUDE_FILE(*crtend?.o *crtend.o) .ctors)
		*(SORT(.ctors.*))
		*(.ctors)

		/* .dtors */
 		*crtbegin.o(.dtors)
 		*crtbegin?.o(.dtors)
 		*(EXCLUDE_FILE(*crtend?.o *crtend.o) .dtors)
 		*(SORT(.dtors.*))
 		*(.dtors)

		*(.rodata*)

		KEEP(*(.eh_frame*))
	} > APP

	.ARM.extab :
	{
		*(.ARM.extab* .gnu.linkonce.armextab.*)
	} > APP

	__exidx_start = .;
	.ARM.exidx :
	{
		*(.ARM.exidx* .gnu.linkonce.armexidx.*)
	} > APP
	__exidx_end = .;

	__etext = .;

	.data : AT (__etext)
	{
		__data_start__ = .;
		*(vtable)
		*(.data*)

		. = ALIGN(4);
		/* preinit data */
		PROVIDE_HIDDEN (__preinit_array_start = .);
		KEEP(*(.preinit_array))
		PROVIDE_HIDDEN (__preinit_array_end = .);

		. = ALIGN(4);
		/* init data */
		PROVIDE_HIDDEN (__init_array_start = .);
		KEEP(*(SORT(.init_array.*)))
		KEEP(*(.init_array))
		PROVIDE_HIDDEN (__init_array_end = .);


		. = ALIGN(4);
		/* finit data */
		PROVIDE_HIDDEN (__fini_array_start = .);
		KEEP(*(SORT(.fini_array.*)))
		KEEP(*(.fini_array))
		PROVIDE_HIDDEN (__fini_array_end = .);

		KEEP(*(.jcr*))
		. = ALIGN(4);
		/* All data end */
		__data_end__ = .;

	} > RAMAPP

	.bss :
	{
		. = ALIGN(4);
		__bss_start__ = .;
		*(.bss*)
		*(COMMON)
		. = ALIGN(4);
		__bss_end__ = .;
	} > RAMAPP

	.heap (COPY):
	{
		__HeapBase = .;
		__end__ = .;
		end = __end__;
		KEEP(*(.heap*))
		__HeapLimit = .;
	} > RAMAPP

	/* .stack_dummy section doesn't contains any symbols. It is only
	 * used for linker to calculate size of stack sections, and assign
	 * values to stack symbols later */
	.stack_dummy (COPY):
	{
		KEEP(*(.stack*))
	} > RAMAPP

	/* Set stack top to end of RAMBSL, and move stack limit down by
	 * size of stack_dummy section */
	__StackTop = ORIGIN(RAMAPP) + LENGTH(RAMAPP);
	__StackLimit = __StackTop - SIZEOF(.stack_dummy);
	PROVIDE(__stack = __StackTop);

	/* Check if data + heap + stack exceeds RAMAPP limit */
	ASSERT(__StackLimit >= __HeapLimit, "region RAMAPP overflowed with stack")
}
